
#line 2 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer bx_create_buffer
#define yy_delete_buffer bx_delete_buffer
#define yy_scan_buffer bx_scan_buffer
#define yy_scan_string bx_scan_string
#define yy_scan_bytes bx_scan_bytes
#define yy_init_buffer bx_init_buffer
#define yy_flush_buffer bx_flush_buffer
#define yy_load_buffer_state bx_load_buffer_state
#define yy_switch_to_buffer bx_switch_to_buffer
#define yypush_buffer_state bxpush_buffer_state
#define yypop_buffer_state bxpop_buffer_state
#define yyensure_buffer_stack bxensure_buffer_stack
#define yy_flex_debug bx_flex_debug
#define yyin bxin
#define yyleng bxleng
#define yylex bxlex
#define yylineno bxlineno
#define yyout bxout
#define yyrestart bxrestart
#define yytext bxtext
#define yywrap bxwrap
#define yyalloc bxalloc
#define yyrealloc bxrealloc
#define yyfree bxfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define bx_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer bx_create_buffer
#endif

#ifdef yy_delete_buffer
#define bx_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer bx_delete_buffer
#endif

#ifdef yy_scan_buffer
#define bx_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer bx_scan_buffer
#endif

#ifdef yy_scan_string
#define bx_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string bx_scan_string
#endif

#ifdef yy_scan_bytes
#define bx_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes bx_scan_bytes
#endif

#ifdef yy_init_buffer
#define bx_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer bx_init_buffer
#endif

#ifdef yy_flush_buffer
#define bx_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer bx_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define bx_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state bx_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define bx_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer bx_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define bxpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state bxpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define bxpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state bxpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define bxensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack bxensure_buffer_stack
#endif

#ifdef yylex
#define bxlex_ALREADY_DEFINED
#else
#define yylex bxlex
#endif

#ifdef yyrestart
#define bxrestart_ALREADY_DEFINED
#else
#define yyrestart bxrestart
#endif

#ifdef yylex_init
#define bxlex_init_ALREADY_DEFINED
#else
#define yylex_init bxlex_init
#endif

#ifdef yylex_init_extra
#define bxlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra bxlex_init_extra
#endif

#ifdef yylex_destroy
#define bxlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy bxlex_destroy
#endif

#ifdef yyget_debug
#define bxget_debug_ALREADY_DEFINED
#else
#define yyget_debug bxget_debug
#endif

#ifdef yyset_debug
#define bxset_debug_ALREADY_DEFINED
#else
#define yyset_debug bxset_debug
#endif

#ifdef yyget_extra
#define bxget_extra_ALREADY_DEFINED
#else
#define yyget_extra bxget_extra
#endif

#ifdef yyset_extra
#define bxset_extra_ALREADY_DEFINED
#else
#define yyset_extra bxset_extra
#endif

#ifdef yyget_in
#define bxget_in_ALREADY_DEFINED
#else
#define yyget_in bxget_in
#endif

#ifdef yyset_in
#define bxset_in_ALREADY_DEFINED
#else
#define yyset_in bxset_in
#endif

#ifdef yyget_out
#define bxget_out_ALREADY_DEFINED
#else
#define yyget_out bxget_out
#endif

#ifdef yyset_out
#define bxset_out_ALREADY_DEFINED
#else
#define yyset_out bxset_out
#endif

#ifdef yyget_leng
#define bxget_leng_ALREADY_DEFINED
#else
#define yyget_leng bxget_leng
#endif

#ifdef yyget_text
#define bxget_text_ALREADY_DEFINED
#else
#define yyget_text bxget_text
#endif

#ifdef yyget_lineno
#define bxget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno bxget_lineno
#endif

#ifdef yyset_lineno
#define bxset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno bxset_lineno
#endif

#ifdef yywrap
#define bxwrap_ALREADY_DEFINED
#else
#define yywrap bxwrap
#endif

#ifdef yyalloc
#define bxalloc_ALREADY_DEFINED
#else
#define yyalloc bxalloc
#endif

#ifdef yyrealloc
#define bxrealloc_ALREADY_DEFINED
#else
#define yyrealloc bxrealloc
#endif

#ifdef yyfree
#define bxfree_ALREADY_DEFINED
#else
#define yyfree bxfree
#endif

#ifdef yytext
#define bxtext_ALREADY_DEFINED
#else
#define yytext bxtext
#endif

#ifdef yyleng
#define bxleng_ALREADY_DEFINED
#else
#define yyleng bxleng
#endif

#ifdef yyin
#define bxin_ALREADY_DEFINED
#else
#define yyin bxin
#endif

#ifdef yyout
#define bxout_ALREADY_DEFINED
#else
#define yyout bxout
#endif

#ifdef yy_flex_debug
#define bx_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug bx_flex_debug
#endif

#ifdef yylineno
#define bxlineno_ALREADY_DEFINED
#else
#define yylineno bxlineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 225
#define YY_END_OF_BUFFER 226
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[504] =
    {   0,
        0,    0,    0,    0,    0,    0,  226,  223,    1,  221,
      209,  223,  222,  195,  206,  223,  211,  212,  196,  193,
      194,  197,  217,  217,  220,  205,  223,  204,  184,  210,
      219,  208,  101,   19,    6,   48,  219,  219,  219,  183,
      219,  219,  219,  219,   13,  219,   14,   53,   27,   11,
      219,   69,  219,   89,   54,  219,  219,  207,  224,    1,
      224,  220,  224,    1,  201,    0,  214,    0,  222,  218,
        0,  213,    0,  216,  217,    0,  199,  202,  200,  203,
      198,  219,  219,  118,  102,  219,  219,  122,  119,  103,
      128,  219,   85,  123,  219,  120,  104,  219,  219,   22,

      174,  124,  219,  121,  127,  105,  219,  219,   24,  177,
      125,  219,  219,  219,  219,  219,  219,  175,  219,  219,
       30,  178,  219,  219,  179,  219,  219,    9,  219,  170,
      219,  219,  180,   17,  219,  219,  219,  219,  219,  219,
      219,  219,  219,    3,  219,   19,  219,  219,  219,  219,
      219,  162,  163,  219,  219,  219,  219,  219,  219,  219,
       80,  219,  219,  126,  219,  219,  219,  129,  219,  176,
      219,  219,  219,  219,  219,  219,  219,  219,  219,   16,
      219,  219,  219,  219,  219,   55,  219,  219,  190,  191,
      192,  218,  215,  219,  101,   35,   34,  219,   50,   49,

      109,  219,  219,  219,  219,   38,    5,  219,   47,  219,
      219,  107,  219,   64,  219,  219,  138,  144,  139,  140,
      143,  141,  219,  171,  142,  145,  219,  219,   30,   41,
      219,  219,   39,  219,  219,   65,   40,  219,  219,   42,
      219,  219,  188,   37,  219,  219,   67,    4,  219,  219,
      219,  219,  219,  219,  219,  164,  165,  166,  167,  168,
      169,  110,  146,  130,  111,  147,  131,  154,  161,  155,
      156,  159,  157,  219,   28,  219,  219,  172,  158,  160,
       81,    2,  219,  106,  219,  219,   66,  219,  108,  219,
       31,  173,  219,  219,  219,  219,   44,  219,  219,   68,

      219,   43,  219,  219,  219,  219,  219,  219,  182,   32,
       33,  219,  219,  219,  185,  219,    7,   23,  219,  219,
      219,  219,   73,   25,  219,   52,  219,  219,  183,   21,
      219,  219,  219,  219,  219,  219,   12,   99,  219,  219,
      219,  219,  219,   51,  112,  148,  132,  113,  149,  133,
      114,  150,  134,  115,  151,  135,  116,  152,  136,  117,
      153,  137,   88,  219,   28,  219,  219,  219,  219,   90,
       78,  219,  219,   26,   10,   72,  219,  219,   63,   36,
      219,  219,  219,  219,  219,  219,  219,  219,   15,   18,
      219,  219,  219,   60,  219,  219,  219,  181,  219,  219,

      219,   91,   45,  219,  219,  219,  219,  219,   79,   61,
      219,  219,  219,  219,  219,   95,  219,  219,  219,   74,
      219,  219,  219,   86,   97,   89,  186,  219,  219,   46,
      100,   70,   96,  219,   17,  219,   82,   20,  219,    0,
      219,  187,  219,  219,  219,  189,  219,  219,    0,  219,
       16,  219,  219,  219,  219,  219,   58,   62,    0,  219,
       56,  219,   59,    0,   94,    0,    0,   87,  219,  219,
      219,    8,  219,    0,  219,  219,    0,    0,    0,   83,
       57,  219,  219,    0,    0,   29,  219,    0,   76,   75,
      219,   71,    0,    0,  219,    0,   93,   84,    0,   92,

       77,   98,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    7,    1,    8,    9,   10,
       11,   12,   13,    1,   14,    1,   15,   16,   17,   18,
       19,   20,   21,   22,   22,   23,   24,    1,   25,   26,
       27,   28,   29,   30,   31,   31,   31,   31,   31,   31,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
        1,   33,    1,   34,   32,    1,   35,   36,   37,   38,

       39,   40,   41,   42,   43,   32,   44,   45,   46,   47,
       48,   49,   50,   51,   52,   53,   54,   55,   56,   57,
       58,   59,    1,   60,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[61] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    1,    1,    1,    1,    1,    1,
        4,    5,    1,    1,    4,    6,    6,    6,    4,    4,
        7,    7,    7,    5,    5,    7,    5,    7,    5,    5,
        5,    7,    7,    7,    5,    7,    8,    5,    5,    1
    } ;

static const flex_int16_t yy_base[516] =
    {   0,
        0,    0,   59,   61,   63,   65,  601,  602,  598,  602,
      572,   64,    0,    0,  602,   61,  602,  602,  602,  602,
      602,  602,   48,    0,  602,   55,  571,   64,  602,  602,
        0,  602,   57,   62,   75,   91,  109,   44,   83,  558,
      113,  153,  140,   27,   62,   69,  146,  542,  183,  200,
      144,  548,   41,   87,  108,  548,  547,  602,  602,  590,
      243,  602,    0,  589,  602,  126,  602,    0,    0,    0,
      132,  602,    0,  167,    0,    0,  602,  602,  602,  602,
      602,    0,  552,    0,  544,  531,  530,    0,    0,  543,
      163,  546,    0,    0,  539,    0,  532,  535,  527,   46,

        0,    0,  158,    0,   73,    0,  545,  536,  539,    0,
        0,  520,   49,  519,  120,  530,  525,  107,  530,  537,
      517,    0,  517,  521,    0,  523,  514,    0,  115,    0,
      516,  512,    0,  513,  140,  516,  527,  508,  503,  521,
      501,  514,  516,    0,  514,  503,  506,  509,  508,  141,
      211,  178,  219,  493,  137,  492,  168,  236,  499,  161,
      512,  493,  497,  178,  501,  500,  488,  496,  501,  166,
      199,  496,  492,  197,  492,  500,  500,  482,  477,  481,
      492,  477,  490,  485,  223,    0,  481,  480,    0,    0,
        0,    0,    0,  480,    0,    0,    0,  472,    0,    0,

        0,  488,  485,  475,  467,    0,    0,  478,  479,  478,
      473,    0,  480,    0,  461,  472,    0,    0,    0,    0,
        0,    0,  477,    0,    0,    0,  458,  469,    0,    0,
      473,  459,    0,  459,  453,    0,    0,  466,  446,    0,
      449,  464,    0,    0,  462,  447,    0,    0,  460,  459,
      459,  449,  449,  443,  440,  234,  238,  265,  266,  269,
      270,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  454,  235,  446,  437,    0,    0,    0,
        0,  263,  433,    0,  449,  435,    0,  435,    0,  444,
        0,    0,  435,  434,  429,  445,    0,  441,  440,    0,

      441,    0,  442,  437,  418,  437,  422,  419,    0,    0,
        0,  413,  417,  425,    0,  433,  424,    0,  413,  425,
      427,  411,    0,    0,  421,    0,  409,  425,    0,    0,
      408,  423,  411,  399,  409,  418,    0,    0,  418,  409,
      398,  411,  391,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  396,    0,  389,  398,  410,  398,    0,
        0,  390,  405,    0,    0,    0,  404,  392,    0,    0,
      400,  385,  402,  393,  393,  395,  394,  379,    0,    0,
      390,  383,  390,    0,  389,  381,  374,    0,  380,  370,

      379,    0,    0,  383,  372,  376,  372,  404,    0,    0,
      364,  363,  364,  373,  374,    0,  373,  369,  365,  395,
      371,  363,  353,    0,    0,  359,    0,  361,  349,    0,
        0,    0,    0,  356,    0,  355,    0,    0,  359,  347,
      359,    0,  358,  353,  349,    0,  380,  341,  166,  350,
        0,  355,  351,  352,  345,  329,    0,    0,  314,  315,
        0,  328,    0,  311,    0,  305,  297,    0,  275,  277,
      284,    0,  272,  263,  266,  281,  268,  269,  272,    0,
        0,  262,  257,  256,  249,    0,  234,  235,  602,  602,
      202,    0,  206,  197,  188,  119,    0,  602,   99,    0,

      602,  602,  602,  326,  334,  342,  347,  355,  361,   97,
      367,   76,  373,  379,  380
    } ;

static const flex_int16_t yy_def[516] =
    {   0,
      503,    1,  504,  504,  504,  504,  503,  503,  503,  503,
      503,  505,  506,  507,  503,  508,  503,  503,  503,  503,
      503,  503,  509,  510,  503,  503,  503,  503,  503,  503,
      511,  503,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  503,  503,  503,
      503,  503,  512,  503,  503,  505,  503,  505,  506,  513,
      508,  503,  508,  509,  510,  514,  503,  503,  503,  503,
      503,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,

      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,   61,  515,
      512,  513,  514,  511,  511,  511,  511,  511,  511,  511,

      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,

      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,

      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  503,
      511,  511,  511,  511,  511,  511,  511,  511,  503,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  503,  511,
      511,  511,  511,  503,  511,  503,  503,  511,  511,  511,
      511,  511,  511,  503,  511,  511,  503,  503,  503,  511,
      511,  511,  511,  503,  503,  511,  511,  503,  503,  503,
      511,  511,  503,  503,  511,  503,  511,  503,  503,  511,

      503,  503,    0,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503
    } ;

static const flex_int16_t yy_nxt[663] =
    {   0,
        8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   24,   24,   24,
       24,   24,   24,   24,   25,   26,   27,   28,   29,   30,
       31,   31,    8,   32,   33,   34,   35,   36,   37,   38,
       39,   40,   41,   42,   43,   44,   45,   46,   47,   48,
       49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
       60,   10,   60,   10,   60,   10,   60,   10,   67,   72,
       75,   75,  139,   61,  140,   61,  180,   63,  191,   63,
       77,   78,  207,   62,  208,   62,  181,   62,  120,   62,
       80,   81,  121,   73,   83,  122,   68,  218,   84,   75,

      141,   85,   86,   89,   76,  219,   90,  142,  143,   95,
       91,   87,   92,   88,   93,  144,   96,  212,   94,   97,
      123,  182,   98,   99,  213,  100,  101,  124,  183,  103,
       67,  102,  104,  105,  125,  106,  107,  184,  108,  502,
       72,  109,  110,  112,  113,  114,  115,  111,  116,  225,
      127,  117,  128,  185,  234,  226,  186,  501,   68,  129,
      118,  130,  221,  131,   73,  119,  235,  132,  133,  133,
      133,  133,  133,  133,  133,  134,  222,  135,  174,  254,
      145,  146,  136,  255,  147,  269,  175,  137,  176,   75,
       75,  239,  240,  270,  177,  178,  148,  138,  149,  151,

      199,  200,  209,  279,  291,  152,  153,  201,  210,  280,
      272,  466,  211,  262,  292,  263,  467,  154,  155,  156,
      157,  158,  284,  503,  273,  159,  256,  257,  258,  259,
      260,  261,  297,  264,  160,  161,  285,  293,  162,  500,
      298,  163,  164,  499,  165,  166,  294,  167,  168,  498,
      169,  170,  171,  497,  265,  172,  266,  173,  189,  189,
      189,  189,  189,  189,  189,  189,  189,  309,  291,  345,
      274,  346,  496,  348,  267,  349,  275,  364,  190,  190,
      190,  276,  495,  190,  190,  190,  365,  277,  190,  347,
      190,  494,  493,  350,  190,  190,  190,  484,  190,  190,

      351,  354,  352,  355,  357,  360,  358,  361,  368,  492,
      491,  369,  490,  485,  489,  488,  487,  486,  483,  482,
      353,  356,  481,  480,  359,  362,   59,   59,   59,   59,
       59,   59,   59,   59,   66,  479,   66,   66,   66,   66,
       66,   66,   69,  478,   69,   69,   69,   69,   69,   69,
       70,   70,   70,   70,   70,   71,  477,   71,   71,   71,
       71,   71,   71,   74,  476,  475,  474,  473,   74,   82,
       82,   82,   82,   82,   82,  192,  192,  192,  192,  192,
      192,  193,  193,  472,  193,  190,  190,  190,  471,  470,
      469,  468,  465,  464,  463,  462,  461,  460,  459,  458,

      457,  456,  455,  454,  453,  452,  451,  450,  449,  448,
      447,  446,  445,  444,  443,  442,  441,  440,  439,  438,
      437,  436,  435,  434,  433,  398,  432,  431,  430,  429,
      428,  427,  426,  425,  424,  423,  422,  421,  420,  419,
      418,  417,  416,  415,  414,  413,  412,  411,  410,  409,
      408,  407,  406,  405,  404,  403,  402,  401,  400,  399,
      398,  397,  396,  395,  394,  393,  392,  391,  390,  389,
      388,  387,  386,  385,  384,  383,  382,  381,  380,  379,
      378,  377,  376,  375,  374,  373,  372,  371,  370,  367,
      366,  363,  344,  343,  342,  341,  340,  339,  338,  337,

      336,  335,  334,  333,  332,  331,  330,  329,  328,  327,
      326,  325,  324,  323,  322,  321,  320,  319,  318,  317,
      316,  315,  314,  313,  312,  311,  310,  308,  307,  306,
      305,  304,  303,  302,  301,  300,  299,  296,  295,  290,
      289,  288,  287,  286,  283,  282,  281,  278,  271,  268,
      253,  252,  251,  250,  249,  248,  247,  246,  245,  244,
      243,  242,  241,  238,  237,  236,  233,  232,  231,  230,
      229,  228,  227,  224,  223,  220,  217,  216,  215,  214,
      206,  205,  204,  203,  202,  198,  197,  196,  195,  194,
       64,   64,  188,  187,  179,  150,  126,   79,   65,   64,

      503,    7,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503
    } ;

static const flex_int16_t yy_chk[663] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        3,    3,    4,    4,    5,    5,    6,    6,   12,   16,
       23,   23,   44,    3,   44,    4,   53,    5,  512,    6,
       26,   26,  100,    3,  100,    4,   53,    5,   38,    6,
       28,   28,   38,   16,   33,   38,   12,  113,   33,  510,

       45,   33,   33,   34,   23,  113,   34,   45,   46,   35,
       34,   33,   34,   33,   34,   46,   35,  105,   34,   35,
       39,   54,   35,   35,  105,   35,   35,   39,   54,   36,
       66,   35,   36,   36,   39,   36,   36,   54,   36,  499,
       71,   36,   36,   37,   37,   37,   37,   36,   37,  118,
       41,   37,   41,   55,  129,  118,   55,  496,   66,   41,
       37,   41,  115,   41,   71,   37,  129,   41,   42,   42,
       42,   42,   42,   42,   42,   43,  115,   43,   51,  150,
       47,   47,   43,  150,   47,  155,   51,   43,   51,   74,
       74,  135,  135,  155,   51,   51,   47,   43,   47,   49,

       91,   91,  103,  160,  170,   49,   49,   91,  103,  160,
      157,  449,  103,  152,  170,  152,  449,   49,   49,   49,
       49,   49,  164,   74,  157,   49,  151,  151,  151,  151,
      151,  151,  174,  152,   49,   50,  164,  171,   50,  495,
      174,   50,   50,  494,   50,   50,  171,   50,   50,  493,
       50,   50,   50,  491,  153,   50,  153,   50,   61,   61,
       61,   61,   61,   61,   61,   61,   61,  185,  185,  256,
      158,  256,  488,  257,  153,  257,  158,  275,   61,   61,
       61,  158,  487,   61,   61,   61,  275,  158,   61,  256,
       61,  485,  484,  257,   61,   61,   61,  474,   61,   61,

      258,  259,  258,  259,  260,  261,  260,  261,  282,  483,
      482,  282,  479,  474,  478,  477,  476,  475,  473,  471,
      258,  259,  470,  469,  260,  261,  504,  504,  504,  504,
      504,  504,  504,  504,  505,  467,  505,  505,  505,  505,
      505,  505,  506,  466,  506,  506,  506,  506,  506,  506,
      507,  507,  507,  507,  507,  508,  464,  508,  508,  508,
      508,  508,  508,  509,  462,  460,  459,  456,  509,  511,
      511,  511,  511,  511,  511,  513,  513,  513,  513,  513,
      513,  514,  514,  455,  514,  515,  515,  515,  454,  453,
      452,  450,  448,  447,  445,  444,  443,  441,  440,  439,

      436,  434,  429,  428,  426,  423,  422,  421,  420,  419,
      418,  417,  415,  414,  413,  412,  411,  408,  407,  406,
      405,  404,  401,  400,  399,  397,  396,  395,  393,  392,
      391,  388,  387,  386,  385,  384,  383,  382,  381,  378,
      377,  373,  372,  369,  368,  367,  366,  364,  343,  342,
      341,  340,  339,  336,  335,  334,  333,  332,  331,  328,
      327,  325,  322,  321,  320,  319,  317,  316,  314,  313,
      312,  308,  307,  306,  305,  304,  303,  301,  299,  298,
      296,  295,  294,  293,  290,  288,  286,  285,  283,  277,
      276,  274,  255,  254,  253,  252,  251,  250,  249,  246,

      245,  242,  241,  239,  238,  235,  234,  232,  231,  228,
      227,  223,  216,  215,  213,  211,  210,  209,  208,  205,
      204,  203,  202,  198,  194,  188,  187,  184,  183,  182,
      181,  180,  179,  178,  177,  176,  175,  173,  172,  169,
      168,  167,  166,  165,  163,  162,  161,  159,  156,  154,
      149,  148,  147,  146,  145,  143,  142,  141,  140,  139,
      138,  137,  136,  134,  132,  131,  127,  126,  124,  123,
      121,  120,  119,  117,  116,  114,  112,  109,  108,  107,
       99,   98,   97,   95,   92,   90,   87,   86,   85,   83,
       64,   60,   57,   56,   52,   48,   40,   27,   11,    9,

        7,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lexer.l"
#line 2 "lexer.l"
/////////////////////////////////////////////////////////////////////////
// $Id$
/////////////////////////////////////////////////////////////////////////

#include <stdlib.h>
#include <string.h>

#ifdef WIN32
	#include <io.h>
	#define YY_NO_UNISTD_H
#endif

#include "debug.h"
#if BX_DEBUGGER

#include "parser.h"

int bx_yyinput(char *buf, int max_size);
#undef YY_INPUT
#define YY_INPUT(buf, ret, max_size) (ret = bx_yyinput(buf, max_size))

static char    *lex_input_ptr = NULL;
static unsigned lex_input_size = 0;

#if BX_SUPPORT_X86_64
  #define LONG_MODE_8BL_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_8BL_REG); }
  #define LONG_MODE_16B_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_16B_REG); }
  #define LONG_MODE_32B_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_32B_REG); }
  #define LONG_MODE_64B_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_64B_REG); }
#else
  #define LONG_MODE_8BL_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
  #define LONG_MODE_16B_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
  #define LONG_MODE_32B_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
  #define LONG_MODE_64B_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
#endif

#if BX_SUPPORT_EVEX
  #define EVEX_OPMASK_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_OPMASK_REG); }
#else
  #define EVEX_OPMASK_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
#endif

#line 1068 "<stdout>"

#line 1070 "<stdout>"

#define INITIAL 0
#define EXAMINE 1
#define DISASM 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 59 "lexer.l"

#line 1291 "<stdout>"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 504 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 602 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 60 "lexer.l"
; // eat up whitespace
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 61 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SET); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 62 "lexer.l"
{ bxlval.bval = 1; return(BX_TOKEN_ON); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 63 "lexer.l"
{ bxlval.bval = 0; return(BX_TOKEN_OFF); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 64 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CRC); }
	YY_BREAK
case 6:
#line 66 "lexer.l"
case 7:
#line 67 "lexer.l"
case 8:
YY_RULE_SETUP
#line 67 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CONTINUE); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 68 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_IF); }
	YY_BREAK
case 10:
#line 70 "lexer.l"
case 11:
YY_RULE_SETUP
#line 70 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_STEPN); }
	YY_BREAK
case 12:
#line 72 "lexer.l"
case 13:
#line 73 "lexer.l"
case 14:
YY_RULE_SETUP
#line 73 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_STEP_OVER); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 74 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LIST_BREAK); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 75 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_VBREAKPOINT); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 76 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LBREAKPOINT); }
	YY_BREAK
case 18:
#line 78 "lexer.l"
case 19:
#line 79 "lexer.l"
case 20:
YY_RULE_SETUP
#line 79 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PBREAKPOINT); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 80 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_INFO); }
	YY_BREAK
case 22:
#line 82 "lexer.l"
case 23:
YY_RULE_SETUP
#line 82 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CONTROL_REGS); }
	YY_BREAK
case 24:
#line 84 "lexer.l"
case 25:
YY_RULE_SETUP
#line 84 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DEBUG_REGS); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 85 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SEGMENT_REGS); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 86 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_R); }
	YY_BREAK
case 28:
#line 88 "lexer.l"
case 29:
YY_RULE_SETUP
#line 88 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_REGS); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 89 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_FPU); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 90 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_XMM); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 91 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_YMM); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 92 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_ZMM); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 93 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_AVX); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 94 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_AMX); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 95 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TILE); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 96 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_MMX); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 97 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CPU); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 98 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_IDT); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 99 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_IVT); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 100 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_GDT); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 101 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LDT); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 102 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TSS); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 103 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TAB); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 104 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LINUX); }
	YY_BREAK
case 46:
#line 106 "lexer.l"
case 47:
#line 107 "lexer.l"
case 48:
YY_RULE_SETUP
#line 107 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DEL_BREAKPOINT); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 108 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_ENABLE_BREAKPOINT); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 109 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DISABLE_BREAKPOINT); }
	YY_BREAK
case 51:
#line 111 "lexer.l"
case 52:
#line 112 "lexer.l"
case 53:
YY_RULE_SETUP
#line 112 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_QUIT); }
	YY_BREAK
case 54:
#line 114 "lexer.l"
case 55:
YY_RULE_SETUP
#line 114 "lexer.l"
{ BEGIN(EXAMINE); bxlval.sval = strdup(bxtext); return(BX_TOKEN_EXAMINE); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 115 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_RESTORE); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 116 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WRITEMEM); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 117 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LOADMEM); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 118 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SETPMEM); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 119 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DEREF); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 120 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_QUERY); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 121 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PENDING); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 122 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TAKE); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 123 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DMA); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 124 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_IRQ); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 125 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SMI); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 126 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_NMI); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 127 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TLB); }
	YY_BREAK
case 69:
#line 129 "lexer.l"
case 70:
YY_RULE_SETUP
#line 129 "lexer.l"
{ BEGIN(DISASM); bxlval.sval = strdup(bxtext); return(BX_TOKEN_DISASM); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 130 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_INSTRUMENT); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 131 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_STOP); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 132 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DOIT); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 133 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TRACE); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 134 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TRACEREG); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 135 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TRACEMEM); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 136 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SWITCH_MODE); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 137 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SIZE); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 138 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PTIME); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 139 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TIMEBP); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 140 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TIMEBP_ABSOLUTE); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 141 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_MODEBP); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 142 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_VMEXITBP); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 143 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PRINT_STACK); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 144 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_BT); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 145 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WATCH); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 146 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_UNWATCH); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 147 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_READ); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 148 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WRITE); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 149 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SHOW); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 150 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LOAD_SYMBOLS); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 151 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SET_MAGIC_BREAK_POINTS); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 152 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CLEAR_MAGIC_BREAK_POINTS); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 153 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SYMBOLS); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 154 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LIST_SYMBOLS); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 155 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_GLOBAL); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 156 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WHERE); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 157 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PRINT_STRING); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 158 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PAGE); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 159 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DEVICE); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 160 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_ALL); }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 161 "lexer.l"
{ bxlval.uval = BX_8BIT_REG_AL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 162 "lexer.l"
{ bxlval.uval = BX_8BIT_REG_BL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 163 "lexer.l"
{ bxlval.uval = BX_8BIT_REG_CL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 164 "lexer.l"
{ bxlval.uval = BX_8BIT_REG_DL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 165 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_SIL); }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 166 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_DIL); }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 167 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_SPL); }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 168 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_BPL); }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 169 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_R8);  }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 170 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_R9);  }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 171 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_R10); }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 172 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_R11); }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 173 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_R12); }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 174 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_R13); }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 175 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_R14); }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 176 "lexer.l"
{ LONG_MODE_8BL_REG(BX_8BIT_REG_R15); }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 177 "lexer.l"
{ bxlval.uval = BX_8BIT_REG_AH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 178 "lexer.l"
{ bxlval.uval = BX_8BIT_REG_BH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 179 "lexer.l"
{ bxlval.uval = BX_8BIT_REG_CH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 180 "lexer.l"
{ bxlval.uval = BX_8BIT_REG_DH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 181 "lexer.l"
{ bxlval.uval = BX_16BIT_REG_AX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 182 "lexer.l"
{ bxlval.uval = BX_16BIT_REG_BX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 183 "lexer.l"
{ bxlval.uval = BX_16BIT_REG_CX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 184 "lexer.l"
{ bxlval.uval = BX_16BIT_REG_DX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 185 "lexer.l"
{ bxlval.uval = BX_16BIT_REG_SI; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 186 "lexer.l"
{ bxlval.uval = BX_16BIT_REG_DI; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 187 "lexer.l"
{ bxlval.uval = BX_16BIT_REG_BP; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 188 "lexer.l"
{ bxlval.uval = BX_16BIT_REG_SP; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 189 "lexer.l"
{ LONG_MODE_16B_REG(BX_16BIT_REG_R8);  }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 190 "lexer.l"
{ LONG_MODE_16B_REG(BX_16BIT_REG_R9);  }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 191 "lexer.l"
{ LONG_MODE_16B_REG(BX_16BIT_REG_R10); }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 192 "lexer.l"
{ LONG_MODE_16B_REG(BX_16BIT_REG_R11); }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 193 "lexer.l"
{ LONG_MODE_16B_REG(BX_16BIT_REG_R12); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 194 "lexer.l"
{ LONG_MODE_16B_REG(BX_16BIT_REG_R13); }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 195 "lexer.l"
{ LONG_MODE_16B_REG(BX_16BIT_REG_R14); }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 196 "lexer.l"
{ LONG_MODE_16B_REG(BX_16BIT_REG_R15); }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 197 "lexer.l"
{ bxlval.uval = BX_32BIT_REG_EAX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 198 "lexer.l"
{ bxlval.uval = BX_32BIT_REG_EBX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 199 "lexer.l"
{ bxlval.uval = BX_32BIT_REG_ECX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 200 "lexer.l"
{ bxlval.uval = BX_32BIT_REG_EDX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 201 "lexer.l"
{ bxlval.uval = BX_32BIT_REG_ESI; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 202 "lexer.l"
{ bxlval.uval = BX_32BIT_REG_EDI; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 203 "lexer.l"
{ bxlval.uval = BX_32BIT_REG_EBP; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 204 "lexer.l"
{ bxlval.uval = BX_32BIT_REG_ESP; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 205 "lexer.l"
{ LONG_MODE_32B_REG(BX_32BIT_REG_R8);  }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 206 "lexer.l"
{ LONG_MODE_32B_REG(BX_32BIT_REG_R9);  }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 207 "lexer.l"
{ LONG_MODE_32B_REG(BX_32BIT_REG_R10); }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 208 "lexer.l"
{ LONG_MODE_32B_REG(BX_32BIT_REG_R11); }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 209 "lexer.l"
{ LONG_MODE_32B_REG(BX_32BIT_REG_R12); }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 210 "lexer.l"
{ LONG_MODE_32B_REG(BX_32BIT_REG_R13); }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 211 "lexer.l"
{ LONG_MODE_32B_REG(BX_32BIT_REG_R14); }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 212 "lexer.l"
{ LONG_MODE_32B_REG(BX_32BIT_REG_R15); }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 213 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_RAX); }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 214 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_RBX); }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 215 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_RCX); }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 216 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_RDX); }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 217 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_RSI); }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 218 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_RDI); }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 219 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_RSP); }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 220 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_RBP); }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 221 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_R8);  }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 222 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_R9);  }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 223 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_R10); }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 224 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_R11); }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 225 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_R12); }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 226 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_R13); }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 227 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_R14); }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 228 "lexer.l"
{ LONG_MODE_64B_REG(BX_64BIT_REG_R15); }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 229 "lexer.l"
{ return(BX_TOKEN_REG_IP); }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 230 "lexer.l"
{ return(BX_TOKEN_REG_EIP);}
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 231 "lexer.l"
{ return(BX_TOKEN_REG_RIP);}
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 232 "lexer.l"
{ return(BX_TOKEN_REG_SSP);}
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 233 "lexer.l"
{ bxlval.uval = BX_SEG_REG_CS; return(BX_TOKEN_CS); }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 234 "lexer.l"
{ bxlval.uval = BX_SEG_REG_ES; return(BX_TOKEN_ES); }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 235 "lexer.l"
{ bxlval.uval = BX_SEG_REG_SS; return(BX_TOKEN_SS); }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 236 "lexer.l"
{ bxlval.uval = BX_SEG_REG_DS; return(BX_TOKEN_DS); }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 237 "lexer.l"
{ bxlval.uval = BX_SEG_REG_FS; return(BX_TOKEN_FS); }
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 238 "lexer.l"
{ bxlval.uval = BX_SEG_REG_GS; return(BX_TOKEN_GS); }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 239 "lexer.l"
{ EVEX_OPMASK_REG(bxtext[1] - '0'); }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 240 "lexer.l"
{ bxlval.uval = 0; return (BX_TOKEN_FLAGS); }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 241 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_XML); }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 242 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_HELP); }
	YY_BREAK
case 184:
#line 244 "lexer.l"
case 185:
YY_RULE_SETUP
#line 244 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CALC); }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 245 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_ADDLYT); }
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 246 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_REMLYT); }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 247 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LYT); }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 248 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SOURCE); }
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 249 "lexer.l"
{ BEGIN(INITIAL); bxlval.sval = strdup(bxtext); return(BX_TOKEN_XFORMAT); }
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 250 "lexer.l"
{ BEGIN(INITIAL); bxlval.sval = strdup(bxtext); return(BX_TOKEN_XFORMAT); }
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 251 "lexer.l"
{ BEGIN(INITIAL); bxlval.sval = strdup(bxtext); return(BX_TOKEN_DISFORMAT); }
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 252 "lexer.l"
{ return ('+'); }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 253 "lexer.l"
{ return ('-'); }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 254 "lexer.l"
{ return (BX_TOKEN_DEREF_CHR); }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 255 "lexer.l"
{ return ('*'); }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 256 "lexer.l"
{ return ('/'); }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 257 "lexer.l"
{ return (BX_TOKEN_RSHIFT); }
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 258 "lexer.l"
{ return (BX_TOKEN_LSHIFT); }
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 259 "lexer.l"
{ return (BX_TOKEN_EQ); }
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 260 "lexer.l"
{ return (BX_TOKEN_NE); }
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 261 "lexer.l"
{ return (BX_TOKEN_LE); }
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 262 "lexer.l"
{ return (BX_TOKEN_GE); }
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 263 "lexer.l"
{ return ('>'); }
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 264 "lexer.l"
{ return ('<'); }
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 265 "lexer.l"
{ return ('&'); }
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 266 "lexer.l"
{ return ('|'); }
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 267 "lexer.l"
{ return ('^'); }
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 268 "lexer.l"
{ return ('!'); }
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 269 "lexer.l"
{ return ('@'); }
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 270 "lexer.l"
{ return ('('); }
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 271 "lexer.l"
{ return (')'); }
	YY_BREAK
case 213:
#line 273 "lexer.l"
case 214:
YY_RULE_SETUP
#line 273 "lexer.l"
{ bxlval.sval = strdup(bxtext+1); bxlval.sval[strlen(bxlval.sval)-1] = 0; return(BX_TOKEN_STRING); }
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 274 "lexer.l"
{ bxlval.uval = strtoull(bxtext, NULL, 16); return(BX_TOKEN_NUMERIC); }
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 275 "lexer.l"
{ bxlval.uval = strtoull(bxtext, NULL, 8); return(BX_TOKEN_NUMERIC); }
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 276 "lexer.l"
{ bxlval.uval = strtoull(bxtext, NULL, 10); return(BX_TOKEN_NUMERIC); }
	YY_BREAK
case 218:
YY_RULE_SETUP
#line 277 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SYMBOLNAME); }
	YY_BREAK
case 219:
YY_RULE_SETUP
#line 278 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 279 "lexer.l"
{ return ('\n'); }
	YY_BREAK
case 221:
/* rule 221 can match eol */
YY_RULE_SETUP
#line 280 "lexer.l"
{ return ('\n'); }
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 281 "lexer.l"
; // eat up comments '//'
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 282 "lexer.l"
{ return(bxtext[0]); }
	YY_BREAK
case 224:
YY_RULE_SETUP
#line 283 "lexer.l"
{ BEGIN(INITIAL); unput(*bxtext); }
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 284 "lexer.l"
ECHO;
	YY_BREAK
#line 2420 "<stdout>"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(EXAMINE):
case YY_STATE_EOF(DISASM):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 504 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 504 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 503);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 284 "lexer.l"


  int
bx_yyinput(char *buf, int max_size)
{
  int len;

  if (lex_input_size == 0) {
    fprintf(stderr, "lex: no characters in string input buffer.\n");
    exit(1);
  }

  len = strlen(lex_input_ptr) + 1;
  if (len > max_size)
    len = max_size;

  memcpy(buf, lex_input_ptr, len);

  return(len);
}

  void
bx_add_lex_input(char *buf)
{
  lex_input_ptr  = buf;
  lex_input_size = strlen(buf);

  // Since we're parsing from strings, flush out
  // all current buffer state, so the next read
  // requests from yyinput

  bx_flush_buffer( YY_CURRENT_BUFFER );
}

#endif /* if BX_DEBUGGER */

